@@ -107,7 +107,3 @@ def main(
 
     click.secho(f'output: {output_file_path}', fg='blue')
     image.save(output_file_path)
-
-
-if __name__ == '__main__':
-    main()
